<?php
// ##############################################################
// cfg/parse.php - for parsing data
// ##############################################################

//
// function parese_html - allows only certain tags, deletes the rest
//

function parse_html($string) {

$string = htmlspecialchars($string, ENT_NOQUOTES);

// basic tags with no parameters and closing tags of more advanced tags
// currently allowing: <b><strong><u><i><em><a><span><img>
$search = array('&lt;b&gt;',
				'&lt;/b&gt;',
				'&lt;strong&gt;',
				'&lt;/strong&gt;',
				'&lt;u&gt;',
				'&lt;/u&gt;',
				'&lt;i&gt;',
				'&lt;/i&gt;',
				'&lt;em&gt;',
				'&lt;/em&gt;',
				'&lt;/a&gt;',
				'&lt;/span&gt;',
				'[quote]',
				'[/quote]',
				'[small]',
				'[/small]');				

$replace = array('<b>',
				'</b>',
				'<strong>',
				'</strong>',
				'<u>',
				'</u>',
				'<i>',
				'</i>',
				'<em>',
				'</em>',
				'</a>',
				'</span>',
				'<div class="forumQuote">',
				'</div>',
				'<br /><span id="postInfo">',
				'</span>');
				
$string = str_replace($search, $replace, $string);

// img, link, span tags - currently allowing all attributes
$search = array('/(&lt;a) (.+)(&gt;)/',
				'/(&lt;span) (.+)(&gt;)/',
				'/(&lt;img) (.+)(&gt;)/');
				
$replace = array('<a \\2>',
				'<span \\2>',
				'<img \\2>');

$string = preg_replace($search, $replace, $string);

$string = nl2br($string);

return $string;

}

// display currently allowed tags
function allowed_html() {

$allowedHTML = htmlspecialchars('<b><strong><i><em><u><img><span><a [href="(url)"]>', ENT_NOQUOTES);

$allowedHTML .= '
<br />The line break tag (&lt;br&gt;) is not necessary; line breaks will be parsed automatically when the post is displayed.';

return $allowedHTML;

}

//
// function truncate - truncates strings but not in the middle of a word.
// variables
// $data - string to be truncated
// $splitlen - length to which the string is to be truncated (approximately) 
//

function truncate($data, $splitlen) {

$words = explode(' ', $data);
$length = 0;
$new_string = '';

for ($i = 0; $i < count($words); $i++) {
	if (($length + strlen($words[$i])) <= $splitlen) {
	$new_string .= ' ' . $words[$i];
	$length += strlen($words[$i]);
	}
	else {
	$new_string .= '...';
	break;
	}
}

return trim($new_string);
}

//
// function parse_filesize - parse filesize into neater form (KB, MB)
// dsize - the file size in bytes
//

function parse_filesize ($dsize) {
            if (strlen($dsize) <= 9 && strlen($dsize) >= 7) {                 
                $dsize = number_format($dsize / 1048576,2);
                return "$dsize MB";
            } 
			else {
                $dsize = number_format($dsize / 1024,2);
                return "$dsize KB";
            }
}

?>